#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

from zope.interface import Interface

from onf_website.skin.public import jquery_tilt
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.shared.common.portlet.interfaces import ISharedContentHeaderPortletSettings
from pyams_default_theme.interfaces import IContentBannerIllustration
from pyams_default_theme.shared.common.portlet.head import SharedContentHeaderPortletRenderer
from pyams_i18n.interfaces import II18n
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config


__docformat__ = 'restructuredtext'

from onf_website import _


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head.pt', layer=IONFBaseLayer)
class BaseHeaderPortletRenderer(SharedContentHeaderPortletRenderer):
    """Base header portlet renderer"""

    label = _("ONF: Standard header with banner (default)")
    illustration_interface = IContentBannerIllustration

    @property
    def illustration(self):
        if not self.settings.display_illustration:
            return None, None, None
        registry = self.request.registry
        illustration = registry.queryMultiAdapter((self.context, self.request),
                                                  self.illustration_interface)
        if (illustration is None) or not illustration.has_data():
            return None, None, None
        data = II18n(illustration).query_attribute('data', request=self.request)
        if data.content_type.startswith('video'):
            return illustration, data, 'video'
        return illustration, data, 'illustration'


#
# Site root head portlet renderer
#

@adapter_config(name='ONF::head-root',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-root.pt', layer=IONFBaseLayer)
class RootHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """Root header portlet renderer"""

    label = _("ONF: Site root header with panoramic illustrations")
    weight = 10


#
# Forest header portlet renderer
#

@adapter_config(name='ONF::head-forest',
                context=(IPortalContext, IPyAMSLayer, Interface,
                         ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head-forest.pt', layer=IONFBaseLayer)
class ForestHeaderPortletRenderer(BaseHeaderPortletRenderer):
    """Forest header portlet renderer"""

    label = _("ONF: Forest header with illustration")
    weight = 50

    resources = (jquery_tilt, )
